@@ -9,13 +9,15 @@ BEGIN {
   }
   *_CAN_USE_INFORMATIVE_NAMES
     = $can_use_informative_names ? sub () { 1 } : sub () { 0 };
+  *_BAD_CLONE_DESTROY
+    = ($] => 5.008009 && $] <= 5.010000) ? sub () { 1 } : sub () { 0 };
 }
 
 use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.007008';
+our $VERSION = '0.007009';
 $VERSION = eval $VERSION;
 
 use Carp ();
@@ -204,18 +206,30 @@ our %EXCEPTIONS;
 our %PACKAGES;
 our %MESSAGES;
 
-sub CLONE {
+sub _update_ex_refs {
   for my $old_id ( keys %EXCEPTIONS ) {
+    my $package = delete $PACKAGES{$old_id};
+    my $message = delete $MESSAGES{$old_id};
     my $ex = delete $EXCEPTIONS{$old_id};
+    next
+      unless defined $ex;
     my $id = refaddr($ex);
-    $EXCEPTIONS{$id} = $ex;
-    $PACKAGES{$id} = delete $PACKAGES{$old_id};
-    $MESSAGES{$id} = delete $MESSAGES{$old_id};
+    weaken($EXCEPTIONS{$id} = $ex);
+    $PACKAGES{$id} = $package;
+    $MESSAGES{$id} = $message;
+  }
+}
+
+sub CLONE {
+  _update_ex_refs;
+  if (_BAD_CLONE_DESTROY) {
+    our %CLONED;
+    @CLONED{keys %EXCEPTIONS} = ();
   }
 }
 
 sub _convert {
-  CLONE;
+  _update_ex_refs;
   if (my $class = blessed(my $ex = $_[0])) {
     return @_
       unless $OPTIONS{objects};
@@ -353,6 +367,11 @@ sub _ex_as_strings {
 
     my $newclass = ref $ex;
 
+    if (Devel::Confess::_BAD_CLONE_DESTROY && exists $Devel::Confess::CLONED{$id}) {
+      my $destroy = $class->can('DESTROY') || return;
+      goto $destroy;
+    }
+
     bless $ex, $class;
 
     Symbol::delete_package($newclass);
